Module: TypedForm
- Defined in:
- lib/typed_form.rb,
lib/typed_form/form.rb,
lib/typed_form/util.rb,
lib/typed_form/version.rb,
lib/typed_form/webhook.rb,
lib/typed_form/api/client.rb,
lib/typed_form/virtual_model.rb,
lib/typed_form/form_data/answers.rb,
lib/typed_form/form_data/question.rb,
lib/typed_form/form_data/parsed_json.rb,
lib/typed_form/form_data/form_submission.rb
Overview
A collection of value objects and utilities for working with data fetched or cached from the Typeform Data API.
Defined Under Namespace
Modules: API, FormData Classes: Form, Util, VirtualModel, Webhook
Constant Summary collapse
- VERSION =
Up-to-date version of gem.
"0.1.8"